/****************************************************************************
** Meta object code from reading C++ file 'kquickstyleitem_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../qqc2-desktop-style-6.29.0/plugin/kquickstyleitem_p.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kquickstyleitem_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15KQuickStyleItemE_t {};
} // unnamed namespace

template <> constexpr inline auto KQuickStyleItem::qt_create_metaobjectdata<qt_meta_tag_ZN15KQuickStyleItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KQuickStyleItem",
        "QML.Element",
        "StyleItem",
        "elementTypeChanged",
        "",
        "textChanged",
        "sunkenChanged",
        "raisedChanged",
        "flatChanged",
        "activeChanged",
        "selectedChanged",
        "hasFocusChanged",
        "onChanged",
        "hoverChanged",
        "horizontalChanged",
        "transientChanged",
        "minimumChanged",
        "maximumChanged",
        "stepChanged",
        "valueChanged",
        "activeControlChanged",
        "styleNameChanged",
        "paintMarginsChanged",
        "hintChanged",
        "propertiesChanged",
        "fontChanged",
        "controlChanged",
        "contentWidthChanged",
        "arg",
        "contentHeightChanged",
        "textureWidthChanged",
        "w",
        "textureHeightChanged",
        "h",
        "leftPaddingChanged",
        "topPaddingChanged",
        "rightPaddingChanged",
        "bottomPaddingChanged",
        "pixelMetric",
        "styleHint",
        "QVariant",
        "updateSizeHint",
        "updateRect",
        "updateBaselineOffset",
        "updateItem",
        "hitTest",
        "x",
        "y",
        "subControlRect",
        "QRectF",
        "subcontrolString",
        "sizeFromContents",
        "QSize",
        "width",
        "height",
        "computeBoundingRect",
        "QRect",
        "QList<QRect>",
        "rects",
        "elidedText",
        "text",
        "elideMode",
        "hasThemeIcon",
        "updateFocusReason",
        "textWidth",
        "textHeight",
        "border",
        "KQuickPadding*",
        "sunken",
        "raised",
        "flat",
        "active",
        "selected",
        "hasFocus",
        "on",
        "hover",
        "horizontal",
        "isTransient",
        "elementType",
        "activeControl",
        "styleName",
        "hints",
        "QVariantMap",
        "properties",
        "font",
        "QFont",
        "minimum",
        "maximum",
        "value",
        "step",
        "paintMargins",
        "contentWidth",
        "contentHeight",
        "textureWidth",
        "textureHeight",
        "leftPadding",
        "topPadding",
        "rightPadding",
        "bottomPadding",
        "control",
        "QQuickItem*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'elementTypeChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sunkenChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'raisedChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'flatChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectedChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasFocusChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hoverChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'horizontalChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transientChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximumChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stepChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'valueChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeControlChanged'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'styleNameChanged'
        QtMocHelpers::SignalData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paintMarginsChanged'
        QtMocHelpers::SignalData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hintChanged'
        QtMocHelpers::SignalData<void()>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'propertiesChanged'
        QtMocHelpers::SignalData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontChanged'
        QtMocHelpers::SignalData<void()>(25, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'controlChanged'
        QtMocHelpers::SignalData<void()>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contentWidthChanged'
        QtMocHelpers::SignalData<void(int)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Signal 'contentHeightChanged'
        QtMocHelpers::SignalData<void(int)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Signal 'textureWidthChanged'
        QtMocHelpers::SignalData<void(int)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
        // Signal 'textureHeightChanged'
        QtMocHelpers::SignalData<void(int)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
        // Signal 'leftPaddingChanged'
        QtMocHelpers::SignalData<void()>(34, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'topPaddingChanged'
        QtMocHelpers::SignalData<void()>(35, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rightPaddingChanged'
        QtMocHelpers::SignalData<void()>(36, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bottomPaddingChanged'
        QtMocHelpers::SignalData<void()>(37, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pixelMetric'
        QtMocHelpers::SlotData<int(const QString &)>(38, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'styleHint'
        QtMocHelpers::SlotData<QVariant(const QString &)>(39, 4, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'updateSizeHint'
        QtMocHelpers::SlotData<void()>(41, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateRect'
        QtMocHelpers::SlotData<void()>(42, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateBaselineOffset'
        QtMocHelpers::SlotData<void()>(43, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateItem'
        QtMocHelpers::SlotData<void()>(44, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hitTest'
        QtMocHelpers::SlotData<QString(int, int)>(45, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 46 }, { QMetaType::Int, 47 },
        }}),
        // Slot 'subControlRect'
        QtMocHelpers::SlotData<QRectF(const QString &)>(48, 4, QMC::AccessPublic, 0x80000000 | 49, {{
            { QMetaType::QString, 50 },
        }}),
        // Slot 'sizeFromContents'
        QtMocHelpers::SlotData<QSize(int, int)>(51, 4, QMC::AccessPublic, 0x80000000 | 52, {{
            { QMetaType::Int, 53 }, { QMetaType::Int, 54 },
        }}),
        // Slot 'computeBoundingRect'
        QtMocHelpers::SlotData<QRect(const QList<QRect> &)>(55, 4, QMC::AccessPublic, 0x80000000 | 56, {{
            { 0x80000000 | 57, 58 },
        }}),
        // Slot 'elidedText'
        QtMocHelpers::SlotData<QString(const QString &, int, int)>(59, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 60 }, { QMetaType::Int, 61 }, { QMetaType::Int, 53 },
        }}),
        // Slot 'hasThemeIcon'
        QtMocHelpers::SlotData<bool(const QString &) const>(62, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'updateFocusReason'
        QtMocHelpers::SlotData<void()>(63, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'textWidth'
        QtMocHelpers::MethodData<qreal(const QString &)>(64, 4, QMC::AccessPublic, QMetaType::QReal, {{
            { QMetaType::QString, 4 },
        }}),
        // Method 'textHeight'
        QtMocHelpers::MethodData<qreal(const QString &)>(65, 4, QMC::AccessPublic, QMetaType::QReal, {{
            { QMetaType::QString, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'border'
        QtMocHelpers::PropertyData<KQuickPadding*>(66, 0x80000000 | 67, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sunken'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'raised'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'flat'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'selected'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'hasFocus'
        QtMocHelpers::PropertyData<bool>(73, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'on'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'hover'
        QtMocHelpers::PropertyData<bool>(75, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'horizontal'
        QtMocHelpers::PropertyData<bool>(76, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isTransient'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 11),
        // property 'elementType'
        QtMocHelpers::PropertyData<QString>(78, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(60, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'activeControl'
        QtMocHelpers::PropertyData<QString>(79, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'styleName'
        QtMocHelpers::PropertyData<QString>(80, QMetaType::QString, QMC::DefaultPropertyFlags, 17),
        // property 'hints'
        QtMocHelpers::PropertyData<QVariantMap>(81, 0x80000000 | 82, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 19),
        // property 'properties'
        QtMocHelpers::PropertyData<QVariantMap>(83, 0x80000000 | 82, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 20),
        // property 'font'
        QtMocHelpers::PropertyData<QFont>(84, 0x80000000 | 85, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 21),
        // property 'minimum'
        QtMocHelpers::PropertyData<int>(86, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'maximum'
        QtMocHelpers::PropertyData<int>(87, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'value'
        QtMocHelpers::PropertyData<int>(88, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'step'
        QtMocHelpers::PropertyData<int>(89, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'paintMargins'
        QtMocHelpers::PropertyData<int>(90, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'contentWidth'
        QtMocHelpers::PropertyData<int>(91, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'contentHeight'
        QtMocHelpers::PropertyData<int>(92, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'textureWidth'
        QtMocHelpers::PropertyData<int>(93, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'textureHeight'
        QtMocHelpers::PropertyData<int>(94, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'leftPadding'
        QtMocHelpers::PropertyData<int>(95, QMetaType::Int, QMC::DefaultPropertyFlags, 27),
        // property 'topPadding'
        QtMocHelpers::PropertyData<int>(96, QMetaType::Int, QMC::DefaultPropertyFlags, 28),
        // property 'rightPadding'
        QtMocHelpers::PropertyData<int>(97, QMetaType::Int, QMC::DefaultPropertyFlags, 29),
        // property 'bottomPadding'
        QtMocHelpers::PropertyData<int>(98, QMetaType::Int, QMC::DefaultPropertyFlags, 30),
        // property 'control'
        QtMocHelpers::PropertyData<QQuickItem*>(99, 0x80000000 | 100, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 22),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<KQuickStyleItem, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KQuickStyleItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KQuickStyleItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KQuickStyleItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KQuickStyleItemE_t>.metaTypes,
    nullptr
} };

void KQuickStyleItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KQuickStyleItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->elementTypeChanged(); break;
        case 1: _t->textChanged(); break;
        case 2: _t->sunkenChanged(); break;
        case 3: _t->raisedChanged(); break;
        case 4: _t->flatChanged(); break;
        case 5: _t->activeChanged(); break;
        case 6: _t->selectedChanged(); break;
        case 7: _t->hasFocusChanged(); break;
        case 8: _t->onChanged(); break;
        case 9: _t->hoverChanged(); break;
        case 10: _t->horizontalChanged(); break;
        case 11: _t->transientChanged(); break;
        case 12: _t->minimumChanged(); break;
        case 13: _t->maximumChanged(); break;
        case 14: _t->stepChanged(); break;
        case 15: _t->valueChanged(); break;
        case 16: _t->activeControlChanged(); break;
        case 17: _t->styleNameChanged(); break;
        case 18: _t->paintMarginsChanged(); break;
        case 19: _t->hintChanged(); break;
        case 20: _t->propertiesChanged(); break;
        case 21: _t->fontChanged(); break;
        case 22: _t->controlChanged(); break;
        case 23: _t->contentWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->contentHeightChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->textureWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->textureHeightChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->leftPaddingChanged(); break;
        case 28: _t->topPaddingChanged(); break;
        case 29: _t->rightPaddingChanged(); break;
        case 30: _t->bottomPaddingChanged(); break;
        case 31: { int _r = _t->pixelMetric((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 32: { QVariant _r = _t->styleHint((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 33: _t->updateSizeHint(); break;
        case 34: _t->updateRect(); break;
        case 35: _t->updateBaselineOffset(); break;
        case 36: _t->updateItem(); break;
        case 37: { QString _r = _t->hitTest((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 38: { QRectF _r = _t->subControlRect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 39: { QSize _r = _t->sizeFromContents((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QSize*>(_a[0]) = std::move(_r); }  break;
        case 40: { QRect _r = _t->computeBoundingRect((*reinterpret_cast<std::add_pointer_t<QList<QRect>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRect*>(_a[0]) = std::move(_r); }  break;
        case 41: { QString _r = _t->elidedText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 42: { bool _r = _t->hasThemeIcon((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 43: _t->updateFocusReason(); break;
        case 44: { qreal _r = _t->textWidth((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 45: { qreal _r = _t->textHeight((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::elementTypeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::textChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::sunkenChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::raisedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::flatChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::activeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::selectedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::hasFocusChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::onChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::hoverChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::horizontalChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::transientChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::minimumChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::maximumChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::stepChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::valueChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::activeControlChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::styleNameChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::paintMarginsChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::hintChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::propertiesChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::fontChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::controlChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)(int )>(_a, &KQuickStyleItem::contentWidthChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)(int )>(_a, &KQuickStyleItem::contentHeightChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)(int )>(_a, &KQuickStyleItem::textureWidthChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)(int )>(_a, &KQuickStyleItem::textureHeightChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::leftPaddingChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::topPaddingChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::rightPaddingChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickStyleItem::*)()>(_a, &KQuickStyleItem::bottomPaddingChanged, 30))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KQuickPadding* >(); break;
        case 31:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KQuickPadding**>(_v) = _t->border(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->sunken(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->raised(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->flat(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->active(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->selected(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->hasFocus(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->on(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->hover(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->horizontal(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isTransient(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->elementType(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->activeControl(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->styleName(); break;
        case 15: *reinterpret_cast<QVariantMap*>(_v) = _t->hints(); break;
        case 16: *reinterpret_cast<QVariantMap*>(_v) = _t->properties(); break;
        case 17: *reinterpret_cast<QFont*>(_v) = _t->font(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->minimum(); break;
        case 19: *reinterpret_cast<int*>(_v) = _t->maximum(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->value(); break;
        case 21: *reinterpret_cast<int*>(_v) = _t->step(); break;
        case 22: *reinterpret_cast<int*>(_v) = _t->paintMargins(); break;
        case 23: *reinterpret_cast<int*>(_v) = _t->contentWidth(); break;
        case 24: *reinterpret_cast<int*>(_v) = _t->contentHeight(); break;
        case 25: *reinterpret_cast<int*>(_v) = _t->textureWidth(); break;
        case 26: *reinterpret_cast<int*>(_v) = _t->textureHeight(); break;
        case 27: *reinterpret_cast<int*>(_v) = _t->leftPadding(); break;
        case 28: *reinterpret_cast<int*>(_v) = _t->topPadding(); break;
        case 29: *reinterpret_cast<int*>(_v) = _t->rightPadding(); break;
        case 30: *reinterpret_cast<int*>(_v) = _t->bottomPadding(); break;
        case 31: *reinterpret_cast<QQuickItem**>(_v) = _t->control(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setSunken(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setRaised(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setFlat(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setActive(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setSelected(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setHasFocus(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setOn(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setHover(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setHorizontal(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setTransient(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setElementType(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setText(*reinterpret_cast<QString*>(_v)); break;
        case 13: _t->setActiveControl(*reinterpret_cast<QString*>(_v)); break;
        case 15: _t->setHints(*reinterpret_cast<QVariantMap*>(_v)); break;
        case 16: _t->setProperties(*reinterpret_cast<QVariantMap*>(_v)); break;
        case 17: _t->setFont(*reinterpret_cast<QFont*>(_v)); break;
        case 18: _t->setMinimum(*reinterpret_cast<int*>(_v)); break;
        case 19: _t->setMaximum(*reinterpret_cast<int*>(_v)); break;
        case 20: _t->setValue(*reinterpret_cast<int*>(_v)); break;
        case 21: _t->setStep(*reinterpret_cast<int*>(_v)); break;
        case 22: _t->setPaintMargins(*reinterpret_cast<int*>(_v)); break;
        case 23: _t->setContentWidth(*reinterpret_cast<int*>(_v)); break;
        case 24: _t->setContentHeight(*reinterpret_cast<int*>(_v)); break;
        case 25: _t->setTextureWidth(*reinterpret_cast<int*>(_v)); break;
        case 26: _t->setTextureHeight(*reinterpret_cast<int*>(_v)); break;
        case 31: _t->setControl(*reinterpret_cast<QQuickItem**>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 15: _t->resetHints(); break;
        case 17: _t->resetFont(); break;
        default: break;
        }
    }
}

const QMetaObject *KQuickStyleItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KQuickStyleItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KQuickStyleItemE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int KQuickStyleItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 46)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 46;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 46)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 46;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void KQuickStyleItem::elementTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KQuickStyleItem::textChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KQuickStyleItem::sunkenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KQuickStyleItem::raisedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KQuickStyleItem::flatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KQuickStyleItem::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KQuickStyleItem::selectedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KQuickStyleItem::hasFocusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KQuickStyleItem::onChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KQuickStyleItem::hoverChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KQuickStyleItem::horizontalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KQuickStyleItem::transientChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void KQuickStyleItem::minimumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void KQuickStyleItem::maximumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void KQuickStyleItem::stepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void KQuickStyleItem::valueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void KQuickStyleItem::activeControlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void KQuickStyleItem::styleNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void KQuickStyleItem::paintMarginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void KQuickStyleItem::hintChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void KQuickStyleItem::propertiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void KQuickStyleItem::fontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void KQuickStyleItem::controlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void KQuickStyleItem::contentWidthChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void KQuickStyleItem::contentHeightChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void KQuickStyleItem::textureWidthChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void KQuickStyleItem::textureHeightChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void KQuickStyleItem::leftPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void KQuickStyleItem::topPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void KQuickStyleItem::rightPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void KQuickStyleItem::bottomPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}
QT_WARNING_POP
